.. vim: set ft=rst fenc=utf-8 tw=72 nowrap:

************
Dependencies
************

**PynFact!** is coded in Python 3.7.3, but works in any Python version
3.6.*.

Dependency list:

**docutils** (``docutils >= 0.1.4``):
    Python Documentation Utilities.

**feedgen** (``feedgen >= 0.9.0``):
    Feed Generator (Atom, RSS, Podcasts).

**python-dateutil** (``python-dateutil >= 2.0``):
    Extensions to the standard Python datetime module.

**Jinja2** (``jinja2 >= 2.7``):
    A small but fast and easy to use stand-alone template engine written
    in pure Python.

**Markdown** (``markdown >= 3.0.0``):
    Python implementation of Markdown.

**Pygments** (``pygments >= 1.0``):
    Syntax highlighting package written in Python.

**PyYAML** (``pyyaml >=5.1``):
    YAML parser and emitter for Python.

**Unidecode** (``unidecode >= 0.4.9``):
    ASCII transliterations of Unicode text.

All dependencies will be installed automatically when installing with
``pip``.  You'll have to install them manually if you use the code
tarball instead of using ``pip``.
